| as.data.frame.openaq_measurements_list | R Documentation |
Method for converting openaq_measurements_list to data frame.
## S3 method for class 'openaq_measurements_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
A list of measurements as returned from list_sensor_measurements. |
row.names |
|
optional |
logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method. |
... |
additional arguments to be passed to or from methods. |
A data frame class of the measurements results, with the following columns:
Numeric. The measurement value.
Numeric. The parameter identifier for the measurement.
Character. The name of the measured parameter.
Character. The units of the measured parameter.
Factor. The label describing the measurement period (e.g. "hour", "day").
Factor. The period of the measurement interval in HH:MM:SS format (e.g. "01:00:00").
POSIXct. The start datetime of the measurement period in local time.
POSIXct. The end datetime of the measurement period in local time.
Numeric. The latitude, geographic Y, value for the measurement.
Numeric. The longitude, geographic X, value for the measurement.
Numeric. The minimum value within the measurement period.
Numeric. The 2nd percentile value within the measurement period.
Numeric. The 25th percentile value within the measurement period.
Numeric. The median value within the measurement period.
Numeric. The 75th percentile value within the measurement period.
Numeric. The 98th percentile value within the measurement period.
Numeric. The maximum value within the measurement period.
Numeric. The average value within the measurement period.
Numeric. The standard deviation of values within the measurement period.
Numeric. The expected number of measurements within the period.
Factor. The expected measurement interval in HH:MM:SS format (e.g. "01:00:00").
Numeric. The observed number of measurements within the period.
Factor. The observer measurement interval in HH:MM:SS format (e.g. "01:00:00").
Numeric. The percentage of expected measurements that were observed.
Numeric. The percentage of time coverage for the measurement period.
The data frame also includes a meta attribute from the original
openaq_measurements_list.
meas <- list_sensor_measurements(23707, limit = 500, as_data_frame = FALSE)
as.data.frame(meas)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.