as.data.frame.openaq_owners_list: Method for converting openaq_owners_list to data frame.

View source: R/owners.R

as.data.frame.openaq_owners_listR Documentation

Method for converting openaq_owners_list to data frame.

Description

Method for converting openaq_owners_list to data frame.

Usage

## S3 method for class 'openaq_owners_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)

Arguments

x

A list of owners as returned from list_owners.

row.names

NULL or a character vector giving the row names for the data frame. Missing values are not allowed.

optional

logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method.

...

additional arguments to be passed to or from methods.

Value

A data frame class of the owners results, with the following columns:

id

Numeric. The owners identifier.

name

Character. The owners name.

The data frame also includes a meta attribute from the original openaq_owners_list.

Examples


owners <- list_owners(as_data_frame = FALSE)
as.data.frame(owners)


openaq documentation built on March 19, 2026, 5:08 p.m.