get_location: Get a single location from the locations resource.

View source: R/locations.R

get_locationR Documentation

Get a single location from the locations resource.

Description

Get a single location from the locations resource.

Usage

get_location(
  locations_id,
  as_data_frame = TRUE,
  dry_run = FALSE,
  rate_limit = FALSE,
  api_key = NULL
)

Arguments

locations_id

An integer representing the locations_id to request.

as_data_frame

A logical for toggling whether to return results as data frame or list, default is TRUE.

dry_run

A logical for toggling a dry run of the request, default is FALSE.

rate_limit

A logical for toggling automatic rate limiting based on rate limit headers, default is FALSE.

api_key

A valid OpenAQ API key string, default is NULL.

Value

A data frame or list of results.

Examples


location <- get_location(42)


openaq documentation built on March 19, 2026, 5:08 p.m.