| list_location_latest | R Documentation |
Get the latest measurements by locations_id.
list_location_latest(
locations_id,
datetime_min = NULL,
limit = NULL,
page = NULL,
as_data_frame = TRUE,
dry_run = FALSE,
rate_limit = FALSE,
api_key = NULL
)
locations_id |
An integer representing the OpenAQ locations_id. |
datetime_min |
A POSIXct datetime specifying the minimum datetime for
filtering results, default is |
limit |
An integer specifying the maximum number of results to return,
default is |
page |
An integer specifying the page number for paginated results,
default is |
as_data_frame |
A logical for toggling whether to return results as
data frame or list, default is |
dry_run |
A logical for toggling a dry run of the request, default is
|
rate_limit |
A logical for toggling automatic rate limiting based on
rate limit headers, default is |
api_key |
A valid OpenAQ API key string, default is |
A data frame or a list of the results.
measurements <- list_location_latest(2178)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.