list_location_sensors: Get a list of a location's sensors.

View source: R/sensors.R

list_location_sensorsR Documentation

Get a list of a location's sensors.

Description

Get a list of a location's sensors.

Usage

list_location_sensors(
  locations_id,
  as_data_frame = TRUE,
  dry_run = FALSE,
  rate_limit = FALSE,
  api_key = NULL
)

Arguments

locations_id

An integer representing the OpenAQ locations_id.

as_data_frame

A logical for toggling whether to return results as data frame or list, default is TRUE.

dry_run

A logical for toggling a dry run of the request, default is FALSE.

rate_limit

A logical for toggling automatic rate limiting based on rate limit headers, default is FALSE.

api_key

A valid OpenAQ API key string, default is NULL.

Value

A data frame or a list of the results.

Examples


sensors <- list_location_sensors(42)


openaq documentation built on March 19, 2026, 5:08 p.m.