openaq-package: openaq: Access Air Quality Data from the 'OpenAQ' API

openaq-packageR Documentation

openaq: Access Air Quality Data from the 'OpenAQ' API

Description

logo

Provides an interface to the 'OpenAQ' API https://openaq.org/, a platform for real-time and historical air quality data from around the world. Users can retrieve measurement data, metadata for sensors and locations for air quality research and monitoring.

Author(s)

Maintainer: Russ Biggs russ@openaq.org (ORCID)

Authors:

Other contributors:

  • Francesca Mills [contributor]

  • OpenAQ dev@openaq.org [copyright holder, funder]

See Also

Useful links:


openaq documentation built on March 19, 2026, 5:08 p.m.