set_base_url: Sets base URL environment variable

View source: R/api.R

set_base_urlR Documentation

Sets base URL environment variable

Description

A helper function to set the OPENAQR_BASE_URL environment variable. This is to override the default URL for testing and custom instance of the API. This function is generally not used by most users except in extraordinary cases.

Usage

set_base_url(base_url)

Arguments

base_url

A character string containing a URL.

Value

No return value, called for side effects.

Examples

set_base_url("https://example.com")


openaq documentation built on March 19, 2026, 5:08 p.m.