| as.data.frame.openaq_instruments_list | R Documentation |
Method for converting openaq_instruments_list to data frame.
## S3 method for class 'openaq_instruments_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
A list of instruments as returned from list_instruments. |
row.names |
|
optional |
logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method. |
... |
additional arguments to be passed to or from methods. |
A data frame class of the instruments results, with the following columns:
Numeric. The instruments identifier.
Character. The name of the measurement instrument.
Logical. Indicates if the instrument is considered a reference monitor.
Numeric. The manufacturers identifier for the manufacturer that makes the instrument.
Factor. The name of manufacturer that makes the instrument.
The data frame also includes a meta attribute from the original
openaq_instruments_list.
instruments <- list_instruments(as_data_frame = FALSE)
as.data.frame(instruments)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.