| as.data.frame.openaq_latest_list | R Documentation |
Method for converting openaq_latest_list to data frame.
## S3 method for class 'openaq_latest_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
A list of latest measurements as returned from list_location_latest or list_parameter_latest. |
row.names |
|
optional |
logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method. |
... |
additional arguments to be passed to or from methods. |
A data frame class of the latest results, with the following columns:
Numeric. The sensors identifier.
Numeric. The locations identifier.
Numeric. The measurement value.
POSIXct. The datetime of the measurement value, in local time
POSIXct. The datetime of the measurement value, in UTC time
Numeric. The latitude, geographic Y, value for the measurement.
Numeric. The longitude, geographic X, value for the measurement.
The data frame also includes a meta attribute from the original
openaq_latest_list.
latest <- list_location_latest(2178, as_data_frame = FALSE)
as.data.frame(latest)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.