| as.data.frame.openaq_licenses_list | R Documentation |
Method for converting openaq_licenses_list to data frame.
## S3 method for class 'openaq_licenses_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
A list of licenses as returned from list_licenses. |
row.names |
|
optional |
logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method. |
... |
additional arguments to be passed to or from methods. |
A data frame class of the licenses results, with the following columns:
Numeric. The licenses identifier.
Character. The license name.
Logical. Indicates whether commerical use is allowed under the license terms.
Logical. Indicates whether attribution is required under the license terms.
Logical. Indicates whether share-alike is required under the license terms.
Logical. Indicates whether modification is allowed under the license terms.
Logical. Indicates whether redistribution is allowed under the license terms.
String. The URL of the license as listed by the upstream source.
The data frame also includes a meta attribute from the original
openaq_licenses_list.
licenses <- list_licenses(as_data_frame = FALSE)
as.data.frame(licenses)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.