| as.data.frame.openaq_locations_list | R Documentation |
Method for converting openaq_locations_list to data frame.
## S3 method for class 'openaq_locations_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
A list of locations as returned from list_locations. |
row.names |
|
optional |
logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method. |
... |
additional arguments to be passed to or from methods. |
A data frame class of the locations results, with the following columns:
Numeric. The locations identifier.
Character. The name of the location.
Logical. Indicates whether the location is stationary or mobile.
Logical. Indicates whether the location is considered a reference monitor.
Factor. The IANA timezone of the location (e.g. "America/New_York").
Numeric. The countries identifier where the location is located.
Character. The name of the country where the location is located
Factor. The ISO 3166-1 alpha-2 country code where the location is located
Numeric.The latitude, geographic Y, value for the measurement.
Numeric. The longitude, geographic X, value for the measurement.
POSIXct. The datetime of the first measurement of this location.
POSIXct. The datetime of the last measurement of this location.
Factor. The name of the owner of the location.
Numeric. The providers identifier for the location.
Character. The name of the provider for the location.
The data frame also includes a meta attribute from the original
openaq_locations_list.
loc <- list_locations(as_data_frame = FALSE)
as.data.frame(loc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.