as.data.frame.openaq_parameters_list: Method for converting openaq_parameters_list to data frame.

View source: R/parameters.R

as.data.frame.openaq_parameters_listR Documentation

Method for converting openaq_parameters_list to data frame.

Description

Method for converting openaq_parameters_list to data frame.

Usage

## S3 method for class 'openaq_parameters_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)

Arguments

x

A list of parameters as returned from list_parameters.

row.names

NULL or a character vector giving the row names for the data frame. Missing values are not allowed.

optional

logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method.

...

additional arguments to be passed to or from methods.

Value

A data frame class of the parameters results, with the following columns:

id

Numeric. The parameter identifier.

name

Character. Name of the parameter.

units

Character. The units used by the parameter.

display_name

Character. The combined name of the parameter and units. May be NA if not provided.

description

Character. Description of the parameter. May be NA if not provided.

The data frame also includes a meta attribute from the original openaq_parameters_list.

Examples


parameters <- list_parameters(as_data_frame = FALSE)
as.data.frame(parameters)


openaq documentation built on March 19, 2026, 5:08 p.m.