| as.data.frame.openaq_parameters_list | R Documentation |
Method for converting openaq_parameters_list to data frame.
## S3 method for class 'openaq_parameters_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
A list of parameters as returned from list_parameters. |
row.names |
|
optional |
logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method. |
... |
additional arguments to be passed to or from methods. |
A data frame class of the parameters results, with the following columns:
Numeric. The parameter identifier.
Character. Name of the parameter.
Character. The units used by the parameter.
Character. The combined name of the parameter and units. May be NA if not provided.
Character. Description of the parameter. May be NA if not provided.
The data frame also includes a meta attribute from the original
openaq_parameters_list.
parameters <- list_parameters(as_data_frame = FALSE)
as.data.frame(parameters)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.