| as.data.frame.openaq_providers_list | R Documentation |
Method for converting openaq_providers_list to data frame.
## S3 method for class 'openaq_providers_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
A list of providers as returned from list_providers. |
row.names |
|
optional |
logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method. |
... |
additional arguments to be passed to or from methods. |
A data frame class of the providers results, with the following columns:
Numeric. The providers identifier.
Character. The name of the provider.
Factor. The name of the source.
Character. Prefixed when exported to file store.
POSIXct. Datetime when the provider was first added to OpenAQ.
POSIXct. Datetime of the first measurement value from the provider.
POSIXct. Datetime of the last measurement value from the provider.
Numeric. Entities identifier for the provider.
Character. A comma delimited list of parameters identifier measured by the provider.
The data frame also includes a meta attribute from the original
openaq_providers_list.
providers <- list_providers(as_data_frame = FALSE)
as.data.frame(providers)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.