| as.data.frame.openaq_sensors_list | R Documentation |
Method for converting openaq_sensors_list to data frame.
## S3 method for class 'openaq_sensors_list'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
A list of sensors as returned from get_sensor or list_location_sensors. |
row.names |
|
optional |
logical. If TRUE, setting row names and converting column names (to syntactic names: see make.names) is optional. Note that all of R's base package as.data.frame() methods use optional only for column names treatment, basically with the meaning of data.frame(*, check.names = !optional). See also the make.names argument of the matrix method. |
... |
additional arguments to be passed to or from methods. |
A data frame class of the sensors results, with the following columns:
Numeric. The sensors identifier.
Character.
Numeric. .
POSIXct. The datetime of the first measurement in UTC.
POSIXct. The datetime of the first measurement in local time.
POSIXct. The datetime of the last measurement in UTC.
POSIXct. The datetime of the last measurement in local time.
Numeric. The minimum measurement value recorded by the sensor.
Numeric. The maximum measurement value recorded by the sensor.
Numeric. The average measurement value recorded by the sensor.
Numeric. The expected number of measurements for the sensor.
Factor. The expected measurement interval in HH:MM:SS format (e.g. "01:00:00").
Numeric. The observed number of measurements for the sensor.
Factor. The observed measurement interval in HH:MM:SS format (e.g. "01:00:00").
Numeric. The percentage of expected measurements that were observed.
Numeric. The percentage of time coverage for the sensor.
Numeric. The most recent measurement value from the sensor.
POSIXct. The datetime of the most recent measurement.
Numeric. The latitude of the most recent measurement location.
Numeric. The longitude of the most recent measurement location
The data frame also includes a meta attribute from the original
openaq_sensors_list.
sensor <- get_sensor(42, as_data_frame = FALSE)
as.data.frame(sensor)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.