| list_countries | R Documentation |
Get a list of countries from the countries resource.
list_countries(
providers_id = NULL,
parameters_id = NULL,
order_by = NULL,
sort_order = NULL,
limit = NULL,
page = NULL,
as_data_frame = TRUE,
dry_run = FALSE,
rate_limit = FALSE,
api_key = NULL
)
providers_id |
A numeric vector of length 1 or more, containing the ID(s) of the providers to use for filtering results. If multiple IDs are provided, results matching any of the IDs will be returned. |
parameters_id |
A numeric vector of length 1 or more, containing the ID(s) of the parameters to use for filtering results. If multiple IDs are provided, results matching any of the IDs will be returned. |
order_by |
A character string specifying the field to order results by. |
sort_order |
A character string specifying sort direction, either |
limit |
An integer specifying the maximum number of results to return, default is |
page |
An integer specifying the page number for paginated results, default is |
as_data_frame |
A logical for toggling whether to return results as
data frame or list, default is |
dry_run |
A logical for toggling a dry run of the request, default is
|
rate_limit |
A logical for toggling automatic rate limiting based on
rate limit headers, default is |
api_key |
A valid OpenAQ API key string, default is |
A data frame or a list of the results.
countries <- list_countries()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.