| list_location_sensors | R Documentation |
Get a list of a location's sensors.
list_location_sensors(
locations_id,
as_data_frame = TRUE,
dry_run = FALSE,
rate_limit = FALSE,
api_key = NULL
)
locations_id |
An integer representing the OpenAQ locations_id. |
as_data_frame |
A logical for toggling whether to return results as
data frame or list, default is |
dry_run |
A logical for toggling a dry run of the request, default is
|
rate_limit |
A logical for toggling automatic rate limiting based on
rate limit headers, default is |
api_key |
A valid OpenAQ API key string, default is |
A data frame or a list of the results.
sensors <- list_location_sensors(42)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.