| openaq-package | R Documentation |
Provides an interface to the 'OpenAQ' API https://openaq.org/, a platform for real-time and historical air quality data from around the world. Users can retrieve measurement data, metadata for sensors and locations for air quality research and monitoring.
Maintainer: Russ Biggs russ@openaq.org (ORCID)
Authors:
Christian Parker chris@talloaks.io
Other contributors:
Francesca Mills [contributor]
OpenAQ dev@openaq.org [copyright holder, funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.