| plot.openaq_locations_data.frame | R Documentation |
Plots location coordinates. If the maps package is installed, a world
boundary overlay is added. Install with install.packages("maps").
## S3 method for class 'openaq_locations_data.frame'
plot(x, y = NULL, ...)
x |
the coordinates of points in the plot. Alternatively, a single plotting structure, function or any R object with a plot method can be provided. |
y |
the y coordinates of points in the plot, optional if x is an appropriate structure. |
... |
Other options passed on to base::plot(). |
Called for its side effect of producing a plot. Returns NULL
invisibly.
df <- list_locations(limit = 100)
plot(df, pch = 19, col = df$provider_name)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.