| set_base_url | R Documentation |
A helper function to set the OPENAQR_BASE_URL environment variable. This is to override the default URL for testing and custom instance of the API. This function is generally not used by most users except in extraordinary cases.
set_base_url(base_url)
base_url |
A character string containing a URL. |
No return value, called for side effects.
set_base_url("https://example.com")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.